Revert "Update docker group ID (#2704)"

This reverts commit 4e516e9348641fae9d6e5ce4858c272ecd2de1e6.
diff --git a/buildkite/bazelci.py b/buildkite/bazelci.py
index 3b07aa8..3153009 100755
--- a/buildkite/bazelci.py
+++ b/buildkite/bazelci.py
@@ -3062,7 +3062,7 @@
         "plugins": {
             "docker#v3.8.0": {
                 "always-pull": True,
-                "additional-groups": ["5995"],
+                "additional-groups": ["999"],
                 "environment": env,
                 "image": image,
                 "network": "host",
diff --git a/pipelines/docker-update.yml b/pipelines/docker-update.yml
index 4731a6e..ae3d5d0 100644
--- a/pipelines/docker-update.yml
+++ b/pipelines/docker-update.yml
@@ -7,7 +7,7 @@
       docker#v3.8.0:
         always-pull: true
         additional-groups:
-          - "5995"
+          - "999"
         environment:
           - ANDROID_HOME
           - ANDROID_NDK_HOME
diff --git a/buildkite/setup-docker.sh b/buildkite/setup-docker.sh
index e8d04ff..cc04f00 100755
--- a/buildkite/setup-docker.sh
+++ b/buildkite/setup-docker.sh
@@ -111,11 +111,11 @@
       "deb [arch=$(dpkg --print-architecture) signed-by=/usr/share/keyrings/docker-archive-keyring.gpg] https://download.docker.com/linux/ubuntu \
       $(lsb_release -cs) stable" | tee /etc/apt/sources.list.d/docker.list > /dev/null
 
-  # Pre-create the docker group with GID 5995 to ensure a stable GID across all runner images.
-  # We fail the image build if GID 5995 is already taken to avoid silent runtime mismatches.
-  groupadd -g 5995 docker || true
-  if [[ "$(getent group docker | cut -d: -f3)" != "5995" ]]; then
-    echo "ERROR: Failed to allocate GID 5995 to docker group."
+  # Pre-create the docker group with GID 999 to ensure a stable GID across all runner images.
+  # We fail the image build if GID 999 is already taken to avoid silent runtime mismatches.
+  groupadd -g 999 docker || true
+  if [[ "$(getent group docker | cut -d: -f3)" != "999" ]]; then
+    echo "ERROR: Failed to allocate GID 999 to docker group."
     exit 1
   fi
 